<p align="center" style="text-align: center">
  <img src="https://i.imgur.com/IYvSZam.gif"
       width="100%"
       alt="Logo of Open Grammar for Python - Natural Language Inference Engine."/>
</p>

<p align="center" style="text-align: center">
    Natural Language Inference Engine
</p>

<p align="center" style="text-align: center">
    <a href="https://stand-with-ukraine.pp.ua">
        <img
            src="https://raw.githubusercontent.com/vshymanskyy/StandWithUkraine/main/badges/StandWithUkraine.svg"
            alt="Stand With Ukraine"
        />
    </a>
</p>

<p align="center" style="text-align: center">
    <a
        href="https://github.com/OpenDebates/OpenGrammar/actions/workflows/main.yml">
            <img
                src="https://github.com/OpenDebates/OpenGrammar/actions/workflows/main.yml/badge.svg"
                alt="Tests"
    />
    </a>
    <a
        href="https://codecov.io/gh/OpenDebates/OpenGrammar">
            <img
                src="https://codecov.io/gh/OpenDebates/OpenGrammar/branch/main/graph/badge.svg?token=Ep07QEelsi"
                alt="codecov" />
    </a>
    <img src="https://img.shields.io/pypi/dm/opengrammar"
        alt="PyPI - Downloads"
    />
    <a
        href="https://opengrammar.rtfd.io/en/latest/?badge=latest">
            <img
                src="https://readthedocs.org/projects/opengrammar/badge/?version=latest"
                    alt="Documentation Status"
            />
    </a>
</p>

## Description

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/opengrammar)

Open Grammar is a set of research tools used to convert formal logic systems into natural language models.

## Installation
```shell
pip install opengrammar
```

## Models Supported

### Formal Languages

- GPLIF: General Predicate Logic with Identity and Function Terms

### Natural Language

- English: [WIP]
